Available modules — Django Chuck 1.0 documentation

### Navigation

- index
- Django Chuck 1.0 documentation »

# Available modules

A brief description of all modules included in Django Chuck.

Please note that this is only a minimum set of modules for the most basic tasks. More apps are available through additional module repositories.

Module | Description
--- | ---
apache | Generates virtualhost for Apache and a mod_wsgi config
cms | Installs django-cms and filer apps
contact | A simple contact form app
core | Installs Django an the basic project structure
django-extensions | Common Django extensions like shell`plus
django-debug-toolbar | The Django debug toolbar
jenkins | Plug and play integration with the Jenkins Coninuous Integration server
mysql | MySQL database settings
nginx | Generates NGiNX virtualhost config
oracle | Oracle database settings
postgres | PostgreSQL database settings
south | The defacto standard for database migrations
unittest | Some wicked, cool unit testing tools
uwsgi | Generates a config and app file for your uWSGI deployment

# Additional module repositories

Currently their is only the extra repository from Notch Interactive available on Github. Feel free to send an email to chuck@notch-interactive.com if you want to add your module repository to this list.

To add another module repository to Django Chuck you have to download it to a local folder and define the `module_basedirs` variable in your config file `~/.django_chuck.conf`.

    module_basedirs="/some/dir/to/additionial-modules","."

### Navigation

- index
- Django Chuck 1.0 documentation »